
*************
Dataset tools
*************

shelephant
----------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_main_parser
    :prog: shelephant

shelephant init
---------------

.. argparse::
    :module: shelephant.dataset
    :func: _init_parser
    :prog: shelephant init

shelephant add
--------------

.. argparse::
    :module: shelephant.dataset
    :func: _add_parser
    :prog: shelephant add

shelephant remove
-----------------

.. argparse::
    :module: shelephant.dataset
    :func: _remove_parser
    :prog: shelephant remove

shelephant update
-----------------

.. argparse::
    :module: shelephant.dataset
    :func: _update_parser
    :prog: shelephant update

shelephant status
-----------------

.. argparse::
    :module: shelephant.dataset
    :func: _status_parser
    :prog: shelephant status

shelephant info
-----------------

.. argparse::
    :module: shelephant.dataset
    :func: _info_parser
    :prog: shelephant info

shelephant lock
---------------

.. argparse::
    :module: shelephant.dataset
    :func: _lock_parser
    :prog: shelephant lock

shelephant cp
-------------

.. argparse::
    :module: shelephant.dataset
    :func: _cp_parser
    :prog: shelephant cp

shelephant mv
-------------

.. argparse::
    :module: shelephant.dataset
    :func: _mv_parser
    :prog: shelephant mv

shelephant rm
-------------

.. argparse::
    :module: shelephant.dataset
    :func: _rm_parser
    :prog: shelephant rm

shelephant pwd
--------------

.. argparse::
    :module: shelephant.dataset
    :func: _pwd_parser
    :prog: shelephant pwd

shelephant gitignore
--------------------

.. argparse::
    :module: shelephant.dataset
    :func: _gitignore_parser
    :prog: shelephant gitignore
